aboutsummaryrefslogtreecommitdiff
path: root/sys/arch/amd64/ioapic.c
diff options
context:
space:
mode:
Diffstat (limited to 'sys/arch/amd64/ioapic.c')
-rw-r--r--sys/arch/amd64/ioapic.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sys/arch/amd64/ioapic.c b/sys/arch/amd64/ioapic.c
index 6c283ac..443142c 100644
--- a/sys/arch/amd64/ioapic.c
+++ b/sys/arch/amd64/ioapic.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2023 Ian Marco Moffett and the VegaOS team.
+ * Copyright (c) 2023 Ian Marco Moffett and the Osmora Team.
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
@@ -10,7 +10,7 @@
* 2. Redistributions in binary form must reproduce the above copyright
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
* 3. Neither the name of VegaOS nor the names of its
* contributors may be used to endorse or promote products derived from
* this software without specific prior written permission.
*
@@ -36,7 +36,7 @@
#include <sys/syslog.h>
__MODULE_NAME("ioapic");
-__KERNEL_META("$Vega$: ioapic.c, Ian Marco Moffett, "
+__KERNEL_META("$Hyra$: ioapic.c, Ian Marco Moffett, "
"I/O APIC driver");
#define IOAPIC_BASE_OFF(off) ((void *)((uintptr_t)ioapic_base + off))
@@ -10,7 +10,7 @@
* notice, this list of conditions and the following disclaimer in the
* documentation and/or other materials provided with the distribution.
- * 3. Neither the name of VegaOS nor the names of its
+ * 3. Neither the name of Hyra nor the names of its
* contributors may be used to endorse or promote products derived from
* this software without specific prior written permission.